DROP TABLE IF EXISTS `opensim`.`agents`;
CREATE TABLE  `opensim`.`agents` (
  `UUID` varchar(36) NOT NULL,
  `sessionID` varchar(36) NOT NULL,
  `secureSessionID` varchar(36) NOT NULL,
  `agentIP` varchar(16) NOT NULL,
  `agentPort` int(11) NOT NULL,
  `agentOnline` tinyint(4) NOT NULL,
  `loginTime` int(11) NOT NULL,
  `logoutTime` int(11) NOT NULL,
  `currentRegion` varchar(36) NOT NULL,
  `currentHandle` bigint(20) unsigned NOT NULL,
  `currentPos` varchar(64) NOT NULL,
  PRIMARY KEY  (`UUID`),
  UNIQUE KEY `session` (`sessionID`),
  UNIQUE KEY `ssession` (`secureSessionID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Rev. 1';

DROP TABLE IF EXISTS `opensim`.`assets`;
CREATE TABLE  `opensim`.`assets` (
  `uuid` varchar(36) NOT NULL,
  `name` varchar(64) NOT NULL,
  `description` varchar(64) NOT NULL,
  `assetType` tinyint(4) NOT NULL,
  `invType` tinyint(4) NOT NULL,
  `local` tinyint(1) NOT NULL,
  `temporary` tinyint(1) NOT NULL,
  `data` longblob NOT NULL,
  PRIMARY KEY  USING BTREE (`uuid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Rev. 1';

DROP TABLE IF EXISTS `opensim`.`inventoryfolders`;
CREATE TABLE  `opensim`.`inventoryfolders` (
  `folderID` varchar(36) NOT NULL default '',
  `agentID` varchar(36) default NULL,
  `parentFolderID` varchar(36) default NULL,
  `folderName` varchar(64) default NULL,
  `type` smallint(6) NOT NULL default '0',
  `version` int(11) NOT NULL default '0',
  PRIMARY KEY  (`folderID`),
  KEY `owner` (`agentID`),
  KEY `parent` (`parentFolderID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Rev. 2';

DROP TABLE IF EXISTS `opensim`.`inventoryitems`;
CREATE TABLE  `opensim`.`inventoryitems` (
  `inventoryID` varchar(36) NOT NULL default '',
  `assetID` varchar(36) default NULL,
  `assetType` int(11) default NULL,
  `parentFolderID` varchar(36) default NULL,
  `avatarID` varchar(36) default NULL,
  `inventoryName` varchar(64) default NULL,
  `inventoryDescription` varchar(64) default NULL,
  `inventoryNextPermissions` int(10) unsigned default NULL,
  `inventoryCurrentPermissions` int(10) unsigned default NULL,
  `invType` int(11) default NULL,
  `creatorID` varchar(36) default NULL,
  `inventoryBasePermissions` int(10) unsigned NOT NULL default '0',
  `inventoryEveryOnePermissions` int(10) unsigned NOT NULL default '0',
  PRIMARY KEY  (`inventoryID`),
  KEY `owner` (`avatarID`),
  KEY `folder` (`parentFolderID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Rev. 2';

DROP TABLE IF EXISTS `opensim`.`land`;
CREATE TABLE  `opensim`.`land` (
  `UUID` varchar(255) NOT NULL,
  `RegionUUID` varchar(255) default NULL,
  `LocalLandID` int(11) default NULL,
  `Bitmap` longblob,
  `Name` varchar(255) default NULL,
  `Description` varchar(255) default NULL,
  `OwnerUUID` varchar(255) default NULL,
  `IsGroupOwned` int(11) default NULL,
  `Area` int(11) default NULL,
  `AuctionID` int(11) default NULL,
  `Category` int(11) default NULL,
  `ClaimDate` int(11) default NULL,
  `ClaimPrice` int(11) default NULL,
  `GroupUUID` varchar(255) default NULL,
  `SalePrice` int(11) default NULL,
  `LandStatus` int(11) default NULL,
  `LandFlags` int(11) default NULL,
  `LandingType` int(11) default NULL,
  `MediaAutoScale` int(11) default NULL,
  `MediaTextureUUID` varchar(255) default NULL,
  `MediaURL` varchar(255) default NULL,
  `MusicURL` varchar(255) default NULL,
  `PassHours` float default NULL,
  `PassPrice` int(11) default NULL,
  `SnapshotUUID` varchar(255) default NULL,
  `UserLocationX` float default NULL,
  `UserLocationY` float default NULL,
  `UserLocationZ` float default NULL,
  `UserLookAtX` float default NULL,
  `UserLookAtY` float default NULL,
  `UserLookAtZ` float default NULL,
  PRIMARY KEY  (`UUID`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

DROP TABLE IF EXISTS `opensim`.`landaccesslist`;
CREATE TABLE  `opensim`.`landaccesslist` (
  `LandUUID` varchar(255) NOT NULL,
  `AccessUUID` varchar(255) default NULL,
  `Flags` int(11) default NULL,
  PRIMARY KEY  (`LandUUID`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

DROP TABLE IF EXISTS `opensim`.`logs`;
CREATE TABLE  `opensim`.`logs` (
  `logID` int(10) unsigned NOT NULL auto_increment,
  `target` varchar(36) default NULL,
  `server` varchar(64) default NULL,
  `method` varchar(64) default NULL,
  `arguments` varchar(255) default NULL,
  `priority` int(11) default NULL,
  `message` varchar(255) default NULL,
  PRIMARY KEY  (`logID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Rev. 1';

DROP TABLE IF EXISTS `opensim`.`primitems`;
CREATE TABLE  `opensim`.`primitems` (
  `itemID` varchar(255) NOT NULL,
  `primID` varchar(255) default NULL,
  `assetID` varchar(255) default NULL,
  `parentFolderID` varchar(255) default NULL,
  `invType` int(11) default NULL,
  `assetType` int(11) default NULL,
  `name` varchar(255) default NULL,
  `description` varchar(255) default NULL,
  `creationDate` bigint(20) default NULL,
  `creatorID` varchar(255) default NULL,
  `ownerID` varchar(255) default NULL,
  `lastOwnerID` varchar(255) default NULL,
  `groupID` varchar(255) default NULL,
  `nextPermissions` int(11) default NULL,
  `currentPermissions` int(11) default NULL,
  `basePermissions` int(11) default NULL,
  `everyonePermissions` int(11) default NULL,
  `groupPermissions` int(11) default NULL,
  PRIMARY KEY  (`itemID`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

DROP TABLE IF EXISTS `opensim`.`prims`;
CREATE TABLE  `opensim`.`prims` (
  `UUID` varchar(255) NOT NULL,
  `RegionUUID` varchar(255) default NULL,
  `ParentID` int(11) default NULL,
  `CreationDate` int(11) default NULL,
  `Name` varchar(255) default NULL,
  `SceneGroupID` varchar(255) default NULL,
  `Text` varchar(255) default NULL,
  `Description` varchar(255) default NULL,
  `SitName` varchar(255) default NULL,
  `TouchName` varchar(255) default NULL,
  `ObjectFlags` int(11) default NULL,
  `CreatorID` varchar(255) default NULL,
  `OwnerID` varchar(255) default NULL,
  `GroupID` varchar(255) default NULL,
  `LastOwnerID` varchar(255) default NULL,
  `OwnerMask` int(11) default NULL,
  `NextOwnerMask` int(11) default NULL,
  `GroupMask` int(11) default NULL,
  `EveryoneMask` int(11) default NULL,
  `BaseMask` int(11) default NULL,
  `PositionX` float default NULL,
  `PositionY` float default NULL,
  `PositionZ` float default NULL,
  `GroupPositionX` float default NULL,
  `GroupPositionY` float default NULL,
  `GroupPositionZ` float default NULL,
  `VelocityX` float default NULL,
  `VelocityY` float default NULL,
  `VelocityZ` float default NULL,
  `AngularVelocityX` float default NULL,
  `AngularVelocityY` float default NULL,
  `AngularVelocityZ` float default NULL,
  `AccelerationX` float default NULL,
  `AccelerationY` float default NULL,
  `AccelerationZ` float default NULL,
  `RotationX` float default NULL,
  `RotationY` float default NULL,
  `RotationZ` float default NULL,
  `RotationW` float default NULL,
  `SitTargetOffsetX` float default NULL,
  `SitTargetOffsetY` float default NULL,
  `SitTargetOffsetZ` float default NULL,
  `SitTargetOrientW` float default NULL,
  `SitTargetOrientX` float default NULL,
  `SitTargetOrientY` float default NULL,
  `SitTargetOrientZ` float default NULL,
  PRIMARY KEY  (`UUID`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

DROP TABLE IF EXISTS `opensim`.`primshapes`;
CREATE TABLE  `opensim`.`primshapes` (
  `UUID` varchar(255) NOT NULL,
  `Shape` int(11) default NULL,
  `ScaleX` float default NULL,
  `ScaleY` float default NULL,
  `ScaleZ` float default NULL,
  `PCode` int(11) default NULL,
  `PathBegin` int(11) default NULL,
  `PathEnd` int(11) default NULL,
  `PathScaleX` int(11) default NULL,
  `PathScaleY` int(11) default NULL,
  `PathShearX` int(11) default NULL,
  `PathShearY` int(11) default NULL,
  `PathSkew` int(11) default NULL,
  `PathCurve` int(11) default NULL,
  `PathRadiusOffset` int(11) default NULL,
  `PathRevolutions` int(11) default NULL,
  `PathTaperX` int(11) default NULL,
  `PathTaperY` int(11) default NULL,
  `PathTwist` int(11) default NULL,
  `PathTwistBegin` int(11) default NULL,
  `ProfileBegin` int(11) default NULL,
  `ProfileEnd` int(11) default NULL,
  `ProfileCurve` int(11) default NULL,
  `ProfileHollow` int(11) default NULL,
  `Texture` longblob,
  `ExtraParams` longblob,
  PRIMARY KEY  (`UUID`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

DROP TABLE IF EXISTS `opensim`.`regions`;
CREATE TABLE  `opensim`.`regions` (
  `uuid` varchar(36) NOT NULL,
  `regionHandle` bigint(20) unsigned NOT NULL,
  `regionName` varchar(32) default NULL,
  `regionRecvKey` varchar(128) default NULL,
  `regionSendKey` varchar(128) default NULL,
  `regionSecret` varchar(128) default NULL,
  `regionDataURI` varchar(255) default NULL,
  `serverIP` varchar(64) default NULL,
  `serverPort` int(10) unsigned default NULL,
  `serverURI` varchar(255) default NULL,
  `locX` int(10) unsigned default NULL,
  `locY` int(10) unsigned default NULL,
  `locZ` int(10) unsigned default NULL,
  `eastOverrideHandle` bigint(20) unsigned default NULL,
  `westOverrideHandle` bigint(20) unsigned default NULL,
  `southOverrideHandle` bigint(20) unsigned default NULL,
  `northOverrideHandle` bigint(20) unsigned default NULL,
  `regionAssetURI` varchar(255) default NULL,
  `regionAssetRecvKey` varchar(128) default NULL,
  `regionAssetSendKey` varchar(128) default NULL,
  `regionUserURI` varchar(255) default NULL,
  `regionUserRecvKey` varchar(128) default NULL,
  `regionUserSendKey` varchar(128) default NULL,
  `regionMapTexture` varchar(36) default NULL,
  `serverHttpPort` int(10) default NULL,
  `serverRemotingPort` int(10) default NULL,
  PRIMARY KEY  (`uuid`),
  KEY `regionName` (`regionName`),
  KEY `regionHandle` (`regionHandle`),
  KEY `overrideHandles` (`eastOverrideHandle`,`westOverrideHandle`,`southOverrideHandle`,`northOverrideHandle`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=FIXED COMMENT='Rev. 1';

DROP TABLE IF EXISTS `opensim`.`terrain`;
CREATE TABLE  `opensim`.`terrain` (
  `RegionUUID` varchar(255) NOT NULL,
  `Revision` int(11) default NULL,
  `Heightfield` longblob,
  PRIMARY KEY  (`RegionUUID`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

DROP TABLE IF EXISTS `opensim`.`userfriends`;
CREATE TABLE  `opensim`.`userfriends` (
  `ownerID` varchar(37) NOT NULL,
  `friendID` varchar(47) NOT NULL,
  `friendPerms` int(11) NOT NULL,
  `datetimestamp` int(11) NOT NULL,
  PRIMARY KEY  (`ownerID`),
  UNIQUE KEY `ownerID` (`ownerID`,`friendID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Rev.1';

DROP TABLE IF EXISTS `opensim`.`users`;
CREATE TABLE  `opensim`.`users` (
  `UUID` varchar(36) NOT NULL default '',
  `username` varchar(32) NOT NULL,
  `lastname` varchar(32) NOT NULL,
  `passwordHash` varchar(32) NOT NULL,
  `passwordSalt` varchar(32) NOT NULL,
  `homeRegion` bigint(20) unsigned default NULL,
  `homeLocationX` float default NULL,
  `homeLocationY` float default NULL,
  `homeLocationZ` float default NULL,
  `homeLookAtX` float default NULL,
  `homeLookAtY` float default NULL,
  `homeLookAtZ` float default NULL,
  `created` int(11) NOT NULL,
  `lastLogin` int(11) NOT NULL,
  `userInventoryURI` varchar(255) default NULL,
  `userAssetURI` varchar(255) default NULL,
  `profileCanDoMask` int(10) unsigned default NULL,
  `profileWantDoMask` int(10) unsigned default NULL,
  `profileAboutText` varchar(255) default NULL,
  `profileFirstText` varchar(255) default NULL,
  `profileImage` varchar(36) default NULL,
  `profileFirstImage` varchar(36) default NULL,
  `webLoginKey` varchar(36) default NULL,
  PRIMARY KEY  (`UUID`),
  UNIQUE KEY `usernames` (`username`,`lastname`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Rev. 2';
