﻿using System;
using System.Collections.Generic;
using System.Text;

using NUnit.Framework;
using Opensim.Framework.Persistence;
using Opensim.Framework.Persistence.mappings;
using Opensim.Framework.Persistence.interfaces;


namespace Opensim.Framework.Persistence.tests
{
    [TestFixture]
    public class AgentsTest : NHibernateTestCase
    {
        private IDaoFactory daoFactory;
        private IAgentsDao agentsDao;

        // Constructor, inicializa objetos comunes (dao + factories)
        [SetUp]
        public void testInit()
        {            // Create the DAO Factory
            this.daoFactory = new NHibernateDaoFactory();

            // Get DAO for user
            this.agentsDao = daoFactory.GetAgentsDao();

        }


        [Test]
        public void createEntity()
        {
            int i = 1;
            Agents ag = new Agents();
            ag.Agentip = "0.0.0.0" + i;
            ag.AgentOnline = 0;
            ag.AgentPort = 1111 + i;
            ag.CurrentHandle = 1 + i;
            ag.CurrentPos = "1,1,1" + i;
            ag.CurrentRegion = "Region" + i;
            ag.LoginTime = 12345 + i;
            ag.LogoutTime = 0 + i;
            ag.SecureSessionid = "securesession" + i;
            ag.Sessionid = "session" + i;

            Assert.IsNull(ag.Uuid);

            // Save user
            agentsDao.Save(ag);

            Assert.IsNotNull(ag.Uuid);
            Assert.IsNotEmpty(ag.Uuid);

        }


        [Test]
        public void updateEntity()
        {
            int i = 1;
            Agents ag = new Agents();
            ag.Agentip = "0.0.0.0" + i;
            ag.AgentOnline = 0;
            ag.AgentPort = 1111 + i;
            ag.CurrentHandle = 1 + i;
            ag.CurrentPos = "1,1,1" + i;
            ag.CurrentRegion = "Region" + i;
            ag.LoginTime = 12345 + i;
            ag.LogoutTime = 0 + i;
            ag.SecureSessionid = "securesession" + i;
            ag.Sessionid = "session" + i;

            Assert.IsNull(ag.Uuid);

            // Save user
            agentsDao.Save(ag);

            Assert.IsNotNull(ag.Uuid);

            string prevRegion = ag.CurrentRegion;


            // Modify entity
            ag.CurrentRegion = "modRegion";

            // Save user
            agentsDao.Save(ag);

            Assert.AreNotEqual(ag.CurrentRegion, prevRegion);


        }


        [Test]
        [ExpectedException(typeof(NHibernate.ObjectDeletedException))]
        public void deleteEntity()
        {
            int i = 1;
            Agents ag = new Agents();
            ag.Agentip = "0.0.0.0" + i;
            ag.AgentOnline = 0;
            ag.AgentPort = 1111 + i;
            ag.CurrentHandle = 1 + i;
            ag.CurrentPos = "1,1,1" + i;
            ag.CurrentRegion = "Region" + i;
            ag.LoginTime = 12345 + i;
            ag.LogoutTime = 0 + i;
            ag.SecureSessionid = "securesession" + i;
            ag.Sessionid = "session" + i;

            Assert.IsNull(ag.Uuid);

            // Save user
            agentsDao.Save(ag);

            Assert.IsNotNull(ag.Uuid);

            string id = ag.Uuid;

            // Delete entity
            agentsDao.Delete(ag);

            // Recover the last id
            Agents ags = agentsDao.GetById(id, false);


        }


    }
}
