﻿using System;
using System.Collections.Generic;
using System.Text;

using NUnit.Framework;
using Opensim.Framework.Persistence;
using Opensim.Framework.Persistence.mappings;
using Opensim.Framework.Persistence.interfaces;


namespace Opensim.Framework.Persistence.tests
{
    [TestFixture]
    public class UsersTest : NHibernateTestCase
    {
        private IDaoFactory daoFactory;
        private IUsersDao usersDao;

        // Constructor, inicializa objetos comunes (dao + factories)
        [SetUp]
        public void testInit()
        {            // Create the DAO Factory
            this.daoFactory = new NHibernateDaoFactory();

            // Get DAO for user
            this.usersDao = daoFactory.GetUsersDao();

        }


        [Test]
        public void createEntity()
        {

            int i = 1;
            Users usr = new Users();
            usr.Username = "username" + i;
            usr.Lastname = "lastname" + i;
            usr.PasswordHash = "passHash" + i;
            usr.PasswordSalt = "passAlt" + i;

            Assert.IsNull(usr.Uuid);

            // Save user
            usersDao.Save(usr);

            Assert.IsNotNull(usr.Uuid);
            Assert.IsNotEmpty(usr.Uuid);

        }


        [Test]
        public void updateEntity()
        {

            // Create an entity and save
            int i = 1;
            Users usr = new Users();
            usr.Username = "username" + i;
            usr.Lastname = "lastname" + i;
            usr.PasswordHash = "passHash" + i;
            usr.PasswordSalt = "passAlt" + i;

            Assert.IsNull(usr.Uuid);

            // Save user
            usersDao.Save(usr);

            Assert.IsNotNull(usr.Uuid);

            string prevName = usr.Username;


            // Modify entity
            usr.Username = "modUsername";

            // Save user
            usersDao.Save(usr);

            Assert.AreNotEqual(usr.Username, prevName);


        }


        [Test]
        [ExpectedException(typeof(NHibernate.ObjectDeletedException))]
        public void deleteEntity()
        {

            // Create an entity and save
            int i = 1;
            Users usr = new Users();
            usr.Username = "username" + i;
            usr.Lastname = "lastname" + i;
            usr.PasswordHash = "passHash" + i;
            usr.PasswordSalt = "passAlt" + i;

            Assert.IsNull(usr.Uuid);

            // Save user
            usersDao.Save(usr);

            Assert.IsNotNull(usr.Uuid);

            string id = usr.Uuid;

            // Delete entity
            usersDao.Delete(usr);

            // Recover the last id
            Users us = usersDao.GetById(id, false);

        }


        //[Test]
        //public void listEntities()
        //{
        //    NHibernateSessionManager.Instance.BeginTransaction();

        //    // Just for testing valida values
        //    // List
        //    List<Users> lst = usersDao.GetAll();

        //    Assert.IsNotNull(lst);
        //    NHibernateSessionManager.Instance.RollbackTransaction();

        //}



    }
}
