using System;
using System.Collections.Generic;
using System.Text;
using Opensim.Framework.Persistence;
using Opensim.Framework.Persistence.mappings;
using Opensim.Framework.Persistence.interfaces;


namespace Test
{
    class Program
    {

        static IDaoFactory daoFactory;


        static void Main(string[] args)
        {
            // Create the DAO Factory
            daoFactory = new NHibernateDaoFactory();

            // Users test
            usersTest();

            // Agents test
            agentsTest();


        }

        static void usersTest()
        {
            // Get DAO for user
            IUsersDao usersDao = daoFactory.GetUsersDao();

            // Get a Full List
            IList<Users> theList = usersDao.GetAll();

            System.Console.WriteLine("Current user list");
            System.Console.WriteLine("-------------------------------------------------------");

            foreach (Users item in theList)
            {
                System.Console.WriteLine(item.Uuid + " " + item.Username + " " + item.Lastname);
            }

            System.Console.WriteLine("-------------------------------------------------------");

            System.Console.WriteLine("Insert: 10 users. (UUID generated by Hibernate)");
            int i = 1;
            for (i = 1; i < 10; i++)
            {

                Users usr = new Users();
                usr.Username = "username" + i;
                usr.Lastname = "lastname" + i;
                usr.PasswordHash = "passHash" + i;
                usr.PasswordSalt = "passAlt" + i;

                // The fields to exclude are INDEXES in DB, not only Ids
                string[] fields = { "Username", "Lastname", "Uuid" };
                Users myUsr = usersDao.GetUniqueByExample(usr, fields);

                // If user exists, don't save
                if (myUsr == null)
                {
                    // Save user
                    usersDao.Save(usr);
                }
                else
                {
                    System.Console.WriteLine("User already exists: " + usr.Username + " " + usr.Lastname);
                }


            }


            theList = usersDao.GetAll();

            System.Console.WriteLine("-------------------------------------------------------");
            System.Console.WriteLine("List after inserts");
            System.Console.WriteLine("-------------------------------------------------------");

            foreach (Users item in theList)
            {
                System.Console.WriteLine(item.Uuid + " " + item.Username + " " + item.Lastname);
            }

            System.Console.WriteLine("-------------------------------------------------------");




            System.Console.WriteLine("Deleting users");

            for (i = 1; i < 10; i++)
            {
                Users usrCrit = new Users();
                usrCrit.Username = "username" + i;
                usrCrit.Lastname = "lastname" + i;
                usrCrit.PasswordHash = "passHash" + i;
                usrCrit.PasswordSalt = "passAlt" + i;

                // The fields to exclude are INDEXES in DB, not only Ids
                string[] fields2 = { "Username", "Lastname", "Uuid" };

                Users delUsr = usersDao.GetUniqueByExample(usrCrit, fields2);
                if (delUsr != null)
                {
                    System.Console.WriteLine("\tUser " + delUsr.Username + " found: deleting.");
                    // Save user
                    usersDao.Delete(delUsr);
                }
                else
                {
                    System.Console.WriteLine("User " + usrCrit.Username + " does not exists");
                }
            }

            // Commit
            usersDao.CommitChanges();


        }


        static void agentsTest()
        {
            // TODO - Check every NOT NULL field

            // Get DAO for user
            IAgentsDao agentsDao = daoFactory.GetAgentsDao();

            // Get a Full List
            IList<Agents> theList = agentsDao.GetAll();

            System.Console.WriteLine("Current agents list");
            System.Console.WriteLine("-------------------------------------------------------");

            foreach (Agents item in theList)
            {
                System.Console.WriteLine(item.Uuid + " " + item.Sessionid + " " + item.SecureSessionid);
            }

            System.Console.WriteLine("-------------------------------------------------------");

            System.Console.WriteLine("Insert: 10 agents. (UUID generated by Hibernate)");
            int i = 1;
            for (i = 1; i < 10; i++)
            {

                Agents usr = new Agents();
                usr.Agentip = "0.0.0.0" + i;
                usr.AgentOnline = 0;
                usr.AgentPort = 1111 + i;
                usr.CurrentHandle = 1 + i;
                usr.CurrentPos = "1,1,1" + i;
                usr.CurrentRegion = "Region" + i;
                usr.LoginTime = 12345 + i;
                usr.LogoutTime = 0 + i;
                usr.SecureSessionid = "securesession" + i;
                usr.Sessionid = "session" + i;

                // The fields to exclude are INDEXES in DB, not only Ids
                string[] fields = { "Session", "SecureSessionid", "Uuid" };
                Agents myUsr = agentsDao.GetUniqueByExample(usr, fields);

                // If user exists, don't save
                if (myUsr == null)
                {
                    // Save user
                    agentsDao.Save(usr);
                }
                else
                {
                    System.Console.WriteLine("Agent already exists: " + usr.Sessionid + " " + usr.SecureSessionid);
                }


            }


            theList = agentsDao.GetAll();

            System.Console.WriteLine("-------------------------------------------------------");
            System.Console.WriteLine("List after inserts");
            System.Console.WriteLine("-------------------------------------------------------");

            foreach (Agents item in theList)
            {
                System.Console.WriteLine(item.Uuid + " " + item.Sessionid + " " + item.SecureSessionid);
            }

            System.Console.WriteLine("-------------------------------------------------------");




            System.Console.WriteLine("Deleting agents");

            for (i = 1; i < 10; i++)
            {
                Agents usrCrit = new Agents();
                usrCrit.Agentip = "0.0.0.0" + i;
                usrCrit.AgentOnline = 0;
                usrCrit.AgentPort = 1111 + i;
                usrCrit.CurrentHandle = 1 + i;
                usrCrit.CurrentPos = "1,1,1" + i;
                usrCrit.CurrentRegion = "Region" + i;
                usrCrit.LoginTime = 12345 + i;
                usrCrit.LogoutTime = 0 + i;
                usrCrit.SecureSessionid = "securesession" + i;
                usrCrit.Sessionid = "session" + i;

                // The fields to exclude are INDEXES in DB, not only Ids
                string[] fields2 = { "Session", "SecureSessionid", "Uuid" };

                Agents delUsr = agentsDao.GetUniqueByExample(usrCrit, fields2);
                if (delUsr != null)
                {
                    System.Console.WriteLine("\tAgent " + delUsr.Sessionid + " found: deleting.");
                    // Save user
                    agentsDao.Delete(delUsr);
                }
                else
                {
                    System.Console.WriteLine("Agent " + usrCrit.Sessionid + " does not exists");
                }
            }

            // Commit
            agentsDao.CommitChanges();


        }






    }
}
